@@ -15,25 +15,22 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 16
-#define ARROW_VERSION_MINOR 1
+#define ARROW_VERSION_MAJOR 17
+#define ARROW_VERSION_MINOR 0
 #define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "16.1.0"
+#define ARROW_VERSION_STRING "17.0.0"
 
-#define ARROW_SO_VERSION "1601"
-#define ARROW_FULL_SO_VERSION "1601.0.0"
+#define ARROW_SO_VERSION "1700"
+#define ARROW_FULL_SO_VERSION "1700.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "17.0.6"
-#define ARROW_CXX_COMPILER_FLAGS "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics"
+#define ARROW_CXX_COMPILER_VERSION "18.1.8"
+#define ARROW_CXX_COMPILER_FLAGS " -march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics  -Wall -Wno-unknown-warning-option -Wno-pass-failed "
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
-#define ARROW_GIT_ID ""
-#define ARROW_GIT_DESCRIPTION ""
-
 #define ARROW_PACKAGE_KIND ""
 
 #define ARROW_COMPUTE
